summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/winpopup/wpcontact.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/winpopup/wpcontact.h')
-rw-r--r--kopete/protocols/winpopup/wpcontact.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/protocols/winpopup/wpcontact.h b/kopete/protocols/winpopup/wpcontact.h
index 6843d6c2..8acd7235 100644
--- a/kopete/protocols/winpopup/wpcontact.h
+++ b/kopete/protocols/winpopup/wpcontact.h
@@ -62,7 +62,7 @@ public:
public slots:
virtual void slotUserInfo();
- void slotChecktqStatus(); // the call back for the checktqStatus timer
+ void slotCheckStatus(); // the call back for the checkStatus timer
void slotNewMessage(const TQString &Body, const TQDateTime &Arrival);
private slots:
@@ -73,7 +73,7 @@ private slots:
private:
bool myWasConnected; // true if protocol connected at last check
- TQTimer checktqStatus; // checks the status of this contact every second or so
+ TQTimer checkStatus; // checks the status of this contact every second or so
// KActionCollection *myActionCollection;
// holds all the protocol specific actions (not many!)
Kopete::ChatSession *m_manager;